
/**
 * @file ohbbhlp.h
 * @version 0.1
 *
 * The main header file of Oh! Babel Helper Library.
 * This library is for Unisoft Babel TOP 2002. ( http://www.unisoft.co.kr )
 * Babel TOP 2002 is commercial Japanese-Korean, Korean-Japanese translation
 * software. Therefore, to use this library, you MUST buy it.
 *
 * This library is for the programmers who are interested in using the Babel
 * TOP 2002 in their own program. Babel TOP 2002 is a translator software for
 * the normal PC users. And it's almost impossible for the programmer to use it
 * because the interface is not revealed. Now, I open the minimum interfaces of
 * Babel TOP 2002 for using the basic translator. This library may be used in
 * the various areas. For example, Babel TOP 2002 can be added to chatting
 * client and the chatting messages can be translated in a real time.
 *
 * This source code is based on guessing without Babel TOP 2002 source code.
 * Therefore, some information may be wrong. Use this library AT YOU OWN RISK.
 *
 * This source code can be distributed freely under BSD license.
 *
 * Taeho Oh ( ohhara@postech.edu , http://ohhara.sarang.net , 2003/11/13 )
 */

#ifndef _OHBBHLP_H_
#define _OHBBHLP_H_

#include <windows.h>

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

#ifndef OHBEXPORT
#define OHBEXPORT __declspec(dllimport)
#endif

#define OHBCALL __stdcall

/**
 * The struct of the translated unicode text.
 */
typedef struct _OHBTRANS
{
  /**
   * The translated unicode text.
   */
  LPCWSTR lpStr;

  /**
   * The reserved area.
   */
  char reserved[28];
} OHBTRANS;

/**
 * Translates Japanese unicode text into Korean unicode text.
 *
 * The returned struct should be passed to OhbJKFree function after copying the
 * translated text. After calling this function, OhbJKFree should be called,
 * otherwise memory leaks will occur.
 * The jpStr should be null-terminated unicode string.
 * Pass null for the reserved argument.
 * This function is multi thread safe. But it's based on the mutual exclusion.
 * Therefore, only one thread can run in this function and the other threads
 * will be suspended during the translation.
 *
 * @param jpStr The Japanese unicode text that will be translated into Korean
 * unicode text.
 * @param reserved The reserved argument.
 * @return The struct pointer of translated Korean unicode text.
 */
OHBEXPORT OHBTRANS * OHBCALL OhbJKTrans(LPCWSTR jpStr, PVOID reserved);

/**
 * Frees translated Japanese unicode text.
 *
 * This should be called after calling OhbJKTrans function, otherwise memory
 * leaks will occur.
 *
 * @param ohbTrans The struct of the translated Japanese unicode text.
 * @return none.
 */
OHBEXPORT void OHBCALL OhbJKFree(OHBTRANS *ohbTrans);

/**
 * Translates Korean unicode text into Japanese unicode text.
 *
 * The returned struct should be passed to OhbKJFree function after copying the
 * translated text. After calling this function, OhbKJFree should be called,
 * otherwise memory leaks will occur.
 * The krStr should be null-terminated unicode string.
 * Pass null for the reserved argument.
 * This function is multi thread safe. But it's based on the mutual exclusion.
 * Therefore, only one thread can run in this function and the other threads
 * will be suspended during the translation.
 *
 * @param krStr The Korean unicode text that will be translated into Japanese
 * unicode text.
 * @param reserved The reserved argument, ust pass NULL.
 * @return The struct pointer of translated Japanese unicode text.
 */
OHBEXPORT OHBTRANS * OHBCALL OhbKJTrans(LPCWSTR krStr, PVOID reserved);

/**
 * Frees translated Korean unicode text.
 *
 * This should be called after calling OhbJKTrans function, otherwise memory
 * leaks will occur.
 *
 * @param ohbTrans The struct of the translated Korean unicode text.
 * @return none.
 */
OHBEXPORT void OHBCALL OhbKJFree(OHBTRANS *ohbTrans);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _OHBBHLP_H_ */
